<?php
/*
	Plugin Name: NetBlog
	Plugin URI: http://netblog.benjaminsommer.com
	Description: Connect posts, pages and external resources (websites, pdf, doc, zip, exe,...). Use Caption, Cross-references, Bibliography, Footnotes. Use of Pingbacks and Blogsearch to dynamically manage your Blog-content (extern links).
	Author: Benjamin Sommer
	Version: 1.4
	Author URI: http://netblog.benjaminsommer.com
	License: CC GNU GPL 2.0 license
 
 */
   		
/*---------------------------------------------------------------------------------------------------------
** LOAD CONFIGURATION
**---------------------------------------------------------------------------------------------------------
*/
include_once('core/config.php');


//----------------------------------------------------------------------------------
// COMMON DB-QUERIES
//----------------------------------------------------------------------------------
include_once( 'core/dbqueries.php' );

//----------------------------------------------------------------------------------
// COMMON DB-QUERIES
//----------------------------------------------------------------------------------
include_once( 'core/uri_hndl.php' );


//----------------------------------------------------------------------------------
// INSTALL, ACTIVATION, DEACTIVATION
//----------------------------------------------------------------------------------
function netblog_install()
{
	global $wpdb;
   
	netblog_register_constants( array('NETBLOG_VERSION','NETBLOG_AUTOCOMPLETE_MINLEN','NETBLOG_BLOGSEARCH_URI','NETBLOG_BLOGSEARCH_MAX',
				'NETBLOG_BLOGSEARCH_PROVIDER_NAME','NETBLOG_BLOGSEARCH_PROVIDER_URI','NETBLOG_WEBSEARCH_URI','NETBLOG_WEBSEARCH_MAX',
				'NETBLOG_WEBSEARCH_PROVIDER_NAME','NETBLOG_WEBSEARCH_PROVIDER_URI','NETBLOG_WEBSEARCH_KEYWORDS' ));
	
	if( !get_option('netblog_caption_gadd') ) add_option('netblog_caption_gadd','delete_pages');
	if( !get_option('netblog_cite_style') ) add_option('netblog_cite_style','apa');
	if( !get_option('netblog_note_format') ) add_option('netblog_note_format','decimal');
	if( !get_option('netblog_mel_read') ) add_option('netblog_mel_read','edit_posts');
	if( !get_option('netblog_mel_edit') ) add_option('netblog_mel_edit','publish_posts');
	if( !get_option('netblog_mel_start_tpl') ) add_option('netblog_mel_start_tpl','new');
	if( !get_option('netblog_mel_tpl') ) add_option('netblog_mel_tpl','true');
	if( !get_option('netblog_mel') ) add_option('netblog_mel','true');	
	
	require_once(ABSPATH . 'wp-admin/includes/upgrade.php');

	// TABLES CAPTION
	$tbl = $wpdb->prefix . constant('NETBLOG_DB_CAPTION');
	if($wpdb->get_var("SHOW TABLES LIKE '$tbl'") != $tbl) {      
		$sql = "CREATE TABLE " . $tbl . " (
			  id BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
			  name VARCHAR(125) NOT NULL,
			  type VARCHAR(32) NOT NULL,
			  num VARCHAR(32) NOT NULL,
			  host BIGINT(20) NOT NULL,
			  host_order INT NOT NULL,
			  title VARCHAR(255),			  
			  local_order INT NOT NULL,
			  print VARCHAR(64) NOT NULL,
			  PRIMARY KEY  (id)
			);";      
		dbDelta($sql);
		add_option("netblog_db_caption_ver", constant('NETBLOG_DB_CAPTION_VER') );
	}
//	$tbl = $wpdb->prefix . constant('NETBLOG_DB_HOST_TREE');
//	if($wpdb->get_var("SHOW TABLES LIKE '$tbl'") != $tbl) {      
//		$sql = "CREATE TABLE " . $tbl . " (
//			  host BIGINT(20) UNSIGNED NOT NULL,
//			  parent BIGINT(20) UNSIGNED NOT NULL,
//			  host_order BIGINT(20) UNSIGNED NOT NULL,
//			  level INT NOT NULL DEFAULT 0,
//			  UNIQUE KEY host_parent  (host,parent)
//			);";      
//		dbDelta($sql);
//		add_option("netblog_db_host_tree_ver", constant('NETBLOG_DB_HOST_TREE_VER') );
//	}
	
	
	if( get_option("netblog_db_ext_ver") == '1.0' )
		return netblog_upgd_db10();
	
	$tbl = $wpdb->prefix . constant('NETBLOG_DB_NET');
	if($wpdb->get_var("SHOW TABLES LIKE '$tbl'") != $tbl) {      
		$sql = "CREATE TABLE " . $tbl . " (
			  id BIGINT(20) UNSIGNED NOT NULL,
			  adj_id BIGINT(20) UNSIGNED NOT NULL,
			  UNIQUE KEY netblogAdj  (id,adj_id)
			);";      
		dbDelta($sql);
		add_option("netblog_db_net_ver", constant('NETBLOG_DB_NET_VER') );
	}
 
	// MAX MEDIUMINT: 16777215 (unsigned)
 	$tbl = $wpdb->prefix . constant('NETBLOG_DB_EXT');
	if($wpdb->get_var("SHOW TABLES LIKE '$tbl'") != $tbl) {      
		$sql = "CREATE TABLE " . $tbl . " (
			  uri_id BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
			  uri VARCHAR(512) NOT NULL,
			  uri_title VARCHAR(127) NOT NULL,
			  flag INT(10),
			  refs MEDIUMINT NOT NULL DEFAULT 1,
			  PRIMARY KEY  (uri_id)
			);";      
   		dbDelta($sql);
		add_option("netblog_db_ext_ver", constant('NETBLOG_DB_EXT_VER') );
	}
	
 	$tbl = $wpdb->prefix . constant('NETBLOG_DB_REL_EXTNODE');
	if($wpdb->get_var("SHOW TABLES LIKE '$tbl'") != $tbl) {      
		$sql = "CREATE TABLE " . $tbl . " (
			  id BIGINT(20) UNSIGNED NOT NULL,
			  uri_id BIGINT(20) UNSIGNED NOT NULL,
			  UNIQUE INDEX `netblog_rel_extnode`  (id,uri_id)
			);";      
   		dbDelta($sql);
		add_option("netblog_db_rel_extnode_ver", constant('NETBLOG_DB_REL_EXTNODE_VER') );
	}
		
}

// FIRST VERSION - NOTHING TO UPGRADE
function netblog_upgrade()
{
	$ver = get_option("netblog_db_ext_ver");
	
	if( $ver == false ) return netblog_install();
	
	if( !get_option( "netblog_version" ) )
		add_option('netblog_version', constant('NETBLOG_VERSION') );
	update_option('netblog_version', constant('NETBLOG_VERSION') );
		
	if( $ver == '1.0')
		return netblog_upgd_db10();
		
	return false;
}

function netblog_upgd_db10()
{
	global $wpdb;
	
	require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
	
	// CREATE TABLE REL EXT
	if( !get_option('netblog_db_rel_extnode_ver') || get_option('netblog_db_rel_extnode_ver') !=  constant('NETBLOG_DB_REL_EXTNODE_VER')) {
	 	$tbl = $wpdb->prefix . constant('NETBLOG_DB_REL_EXTNODE');
		if($wpdb->get_var("SHOW TABLES LIKE '$tbl'") != $tbl) {      
			$sql = "CREATE TABLE " . $tbl . " (
				  id BIGINT(20) UNSIGNED NOT NULL,
				  uri_id BIGINT(20) UNSIGNED NOT NULL,
				  UNIQUE INDEX `netblog_rel_extnode`  (id,uri_id)
				);";   
			//$wpdb->query($sql);   
	   		dbDelta($sql);
	   		
	   		if( !get_option('netblog_db_rel_extnode_ver') )
				add_option("netblog_db_rel_extnode_ver", constant('NETBLOG_DB_REL_EXTNODE_VER') );
			else update_option("netblog_db_rel_extnode_ver", constant('NETBLOG_DB_REL_EXTNODE_VER') );
		}
	}
	
	if( !get_option('netblog_db_ext_ver') ) {
	 	$tbl = $wpdb->prefix . constant('NETBLOG_DB_EXT');
		if($wpdb->get_var("SHOW TABLES LIKE '$tbl'") != $tbl) {      
			$sql = "CREATE TABLE " . $tbl . " (
				  uri_id BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
				  uri VARCHAR(512) NOT NULL,
				  uri_title VARCHAR(127) NOT NULL,
				  flag INT(10),
			  	  refs MEDIUMINT NOT NULL DEFAULT 1,
				  PRIMARY KEY  (uri_id)
				);";      
	   		dbDelta($sql);
			add_option("netblog_db_ext_ver", constant('NETBLOG_DB_EXT_VER') );
		}
		return true;		
	}
	
	// UPDATE TABLE EXT
	if( get_option('netblog_db_ext_ver') <= '1.0' ) {
		$ext = $wpdb->prefix . constant('NETBLOG_DB_EXT');
		$sql = "SELECT * FROM `$ext`";
		$res = $wpdb->get_results($sql, ARRAY_A);
		
			$wpdb->query("DROP TABLE `$ext`");
			     
			$sql = "CREATE TABLE `$ext` (
				  uri_id BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
				  uri VARCHAR(512) NOT NULL,
				  uri_title VARCHAR(127) NOT NULL,
				  flag INT(10),
			 	  refs MEDIUMINT NOT NULL DEFAULT 1,
				  PRIMARY KEY  (uri_id)
				);";
			//$wpdb->query($sql);
	   		dbDelta($sql);
			update_option("netblog_db_ext_ver", constant('NETBLOG_DB_EXT_VER') );
		
		foreach( $res as $row ) {
			netblog_addAdjacent( $row['id'], $row['uri'], true, $row['uri_title'] );
		}
	}	
	return true;
}

function netblog_deactivate()
{
	remove_action('admin_menu', 'netblog_plugin_menu');
}

function netblog_uninstall()
{
	global $wpdb;
	
	// REMOVE DATABASE TABLES
	$dbtbl = array();
	$dbtbl[] = $wpdb->prefix . constant('NETBLOG_DB_NET');
	$dbtbl[] = $wpdb->prefix . constant('NETBLOG_DB_EXT');
	$dbtbl[] = $wpdb->prefix . constant('NETBLOG_DB_REL_EXTNODE');
	
	foreach( $dbtbl as $tbl ) {
		if( $wpdb->get_var("SHOW TABLES LIKE '$tbl'") == $tbl )
			$wpdb->query("DROP TABLE `$tbl`");
	}
	// 	$wpdb->query("DROP TABLE IF EXISTS ".implode(',',$dbtbl) ); 		// ALTERNATIVE METHOD - SOMEWHAT FASTER
	
	
	// REMOVE OPTIONS
	delete_option("netblog_version" );
	delete_option("netblog_db_net_ver" );
	delete_option("netblog_db_ext_ver" );
	delete_option("netblog_db_rel_extnode_ver" );
}

function netblog_register_constants( $array )
{
	foreach( $array as $nm ) {
		if( !defined($nm) ) continue;
		$nmL = strtolower($nm);
		if( !get_option($nmL) )
			add_option($nmL, constant($nm) );
		else update_option($nmL, constant($nm) );			 
	}
}

register_activation_hook(__FILE__,'netblog_install');
register_deactivation_hook(__FILE__,'netblog_deactivate');
register_uninstall_hook(__FILE__, 'netblog_uninstall');




//----------------------------------------------------------------------------------
// TOP-LEVEL ADMIN-MENU
//----------------------------------------------------------------------------------
add_action('admin_init', 'netblog_plugin_admin_init');
add_action('admin_init', 'netblog_plugin_script');
add_action('admin_init', 'netblog_plugin_styles');
//add_action('admin_menu', 'netblog_plugin_menu');				// AMIN MENU DISABLED FOR NOW! UNDER CONSTRUCTION!!!!
add_action('deleted_post', 'netblog_removeNode');
add_action('deleted_post', 'netblog_caption_rmByHost');
add_action('save_post', 'netblog_save_postdata');
add_action('admin_menu', 'netblog_plg');

$isSavePost = false;

function netblog_plugin_admin_init()
{
	wp_register_style('Netblog-plugin-css', WP_PLUGIN_URL . '/netblog/styles/style-admin.css');
	wp_register_script('Netblog-plugin-js', WP_PLUGIN_URL . '/netblog/js/admin.js');
	wp_register_style('Netblog-plugin-css-autocomplete', WP_PLUGIN_URL . '/netblog/styles/autocomplete.css');
	wp_register_script('Netblog-plugin-js-autocomplete', WP_PLUGIN_URL . '/netblog/js/autocomplete.js');
	wp_register_style('Netblog-plugin-css-lister', WP_PLUGIN_URL . '/netblog/styles/lister.css');
	wp_register_script('Netblog-plugin-js-lister', WP_PLUGIN_URL . '/netblog/js/lister.js');
	wp_register_script('Netblog-plugin-js-md5', WP_PLUGIN_URL . '/netblog/js/md5.js');
	wp_register_script('Netblog-plugin-js-fade', WP_PLUGIN_URL . '/netblog/js/fade_hideShow.js');
	wp_register_script('Netblog-plugin-js-timeoutRefresh', WP_PLUGIN_URL . '/netblog/js/setTimeoutRefresh.js');
}

function netblog_plg()
{
	global $current_user;
	
	if( get_option('netblog_mel') == 'true' && current_user_can( get_option('netblog_mel_read') ) )
		$page = add_links_page('Netblog Extern Links', 'NB-MEL', 'publish_posts', 'netblog-main-mk', 'netblog_mel');
		
	if( current_user_can( 'activate_plugins' ) )
		add_options_page('Netblog Settings', 'Netblog', 'manage_options', 'netblog-setting', 'netblog_settings');
}

function netblog_plugin_menu() {

  $page = add_posts_page('Netblog Posts', 'Netblog', 'publish_posts', 'netblog-posts-mk', 'netblog_plugin_options');

  //add_action('admin_print_styles-' . $page, 'netblog_plugin_styles');
  //add_action('admin_print_scripts-' . $page, 'netblog_plugin_script');
}
function netblog_plugin_styles()
{
	wp_enqueue_style('Netblog-plugin-css');
	wp_enqueue_style('Netblog-plugin-css-autocomplete');
	wp_enqueue_style('Netblog-plugin-css-lister');
}
function netblog_plugin_script()
{
	wp_enqueue_script('Netblog-plugin-js');
	wp_enqueue_script('Netblog-plugin-js-autocomplete');
	wp_enqueue_script('Netblog-plugin-js-lister');
	wp_enqueue_script('Netblog-plugin-js-md5');
	wp_enqueue_script('Netblog-plugin-js-fade');
	wp_enqueue_script('Netblog-plugin-js-timeoutRefresh');	
}


function netblog_plugin_options() {
  global $wpdb;

  if (!current_user_can('publish_posts'))  {
    wp_die( __('You do not have sufficient permissions to access this page.') );
  }

}

function netblog_save_postdata($post_id) {
	global $isSavePost, $netblog_capts, $netblog_captCur, $netblog_captNum, $netblog_captPos;
	$netblog_capts = array();
	$netblog_captCur = array();
	$netblog_captNum = array();
	$netblog_captPos = 0;	
	$isSavePost = true;
			
	if (!current_user_can('publish_posts'))  {
		wp_die( __('You do not have sufficient permissions to access this page.') );
	}

//	if ( !wp_verify_nonce( $_POST['netblog_noncename'], plugin_basename(__FILE__) )) {
//		return $post_id;
//	}

	if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) 
		return $post_id;

	if ( 'page' == $_POST['post_type'] ) {
		if ( !current_user_can( 'edit_page', $post_id ) )
			return $post_id;
	} else {
		if ( !current_user_can( 'edit_post', $post_id ) )
			return $post_id;
	}
	
	// UPDATE CAPTION TABLE
	do_shortcode( stripslashes($_POST['post_content']) );

	// CLEAN CAPTION TABLE
	$captionsOld = netblog_caption_by_host($_POST['post_ID']);
	
	foreach( $captionsOld as $res )
		if( !isset($netblog_capts[ $res['type'] ][ $res['name'] ]) )
			netblog_caption_remove($res['name'],$res['type']);
	return true;
}


function netblog_getqs( $remove )
{
	$r;
	if( is_array( $remove) )
		$r = $remove;
	else $r = array($remove);
	
	$s = '?';
	$num = 0;
	if(isset($_GET)) foreach( $_GET as $k=>$v ) {
		if( in_array($k,$r) )
			continue;
		if( $num++ == 0 )
			$s .= "$k=$v";
		else $s .= "&$k=$v";
	}
	return $s;		
}
function netblog_qsval( $key )
{
	if( isset($_GET) && isset($_GET[$key]) ) return $_GET[$key];
	else return '';
}




//----------------------------------------------------------------------------------
// HELPER FUNCTIONS
//----------------------------------------------------------------------------------
function netblog_cstrip( $string, $maxSize, $appendOnExceed )
{
	if( $maxSize > 0 && strlen($string) > $maxSize )
		$string = substr($string,0,$maxSize) . $appendOnExceed;
	return $string;
}

function netblog_mkqs( $add = '', $remove = '' )
{
	$get = $_GET;
	$t = explode('&',$add);
	foreach( $t as $v ) {
		$s = explode('=',$v);
		$get[$s[0]] = $s[1];
	}
	
	$t = explode('&',$remove);
	foreach( $t as $v ) {
		$s = explode('=',$v);
		if( isset($get[$s[0]])) unset($get[$s[0]]);
	}
	
	$out = array();
	foreach( $get as $k=>$v )
		if($k!='')
		$out[] = "$k=$v";
	return implode('&',$out);
}

function netblog_mkurl( $qsadd = '', $qsremove = '' ) 
{
	return basename($_SERVER['SCRIPT_URL']) . '?' . netblog_mkqs($qsadd,$qsremove);
}

function netblog_str2alnum( $string, $trim_whitespace = true )
{
	if( $trim_whitespace )
		return preg_replace("/[^a-zA-Z0-9\s]/", "", $string);
	else return preg_replace("/[^a-zA-Z0-9]/", "", $string);
}

//----------------------------------------------------------------------------------
// NETBLOG-PAGE
//----------------------------------------------------------------------------------
function netblog_mel()
{
	echo '<div class="wrap">
		<div id="icon-link-manager" class="icon32"><br /></div>
		<h2>Netblog - Manage External Links</h2><br />';
		
	$mel_tpl = array( 'new'=>'Just Added', 'popular'=>'Most Popular', 'offline'=>'Offline', 'trash'=>'Trashed' );
	
	$mel_tpl_startup = 'tpl:'. (get_option('netblog_mel_start_tpl'));
	$mel_tpls_user = netblog_mel_tpls();
	?>
	

	
	<div class="netblog-main">
		<div class="netblog-menu">	
			<div class="search">
				<div style="display:inline;cursor:pointer" id="netblog-status-save" onclick="linkSet.flush(0)" title=""></div>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
				Quick Find: <input type="text" value="" onkeyup="searchInput('quickfind','netblog_retrieve(\'' + this.value + '\')');" />
			</div>
			
			<a class="lnk" onclick="netblog_retrieve('tpl:new')">Just Added</a>
			<a class="lnk" onclick="netblog_retrieve('tpl:popular')">Most Popular</a>
			<a class="lnk" onclick="netblog_retrieve('tpl:offline')">Offline</a>
			<a class="lnk" onclick="netblog_retrieve('tpl:trash')">Trashed</a>
			<?php if( get_option('netblog_mel_tpl') == 'true' && sizeof($mel_tpls_user) > 0 ) { ?>
				<a class="lnk" onmouseover="nb_toogle_custommenu()" onclick="hidePlus('nb-mel-custom-sub',2000,500,true,false)"  id="nb-mel-custom">Custom</a>
				<div id="nb-mel-custom-sub" class="netblog-menu-sub">
					<?php foreach( $mel_tpls_user as $nm=>$val )
							echo '<a class="lnk" onclick="netblog_retrieve(\''.$val.'\')" style="display:block;float:none">'.ucfirst($nm).'</a>';
						 ?>
				</div>
			<?php } ?>
			<div class="sep"></div>
			<a class="lnk" onclick="linkSet.restoreElements()">Restore</a>
			<a class="lnk" onclick="linkSet.removeElements()">Trash</a>
			<a class="lnk" onclick="linkSet.removePermanent()">Erase</a>				
			<div class="sep"></div>
			<a class="lnk" onclick="linkSet.updateTitleOfElements()">Update</a>
			<a class="lnk" onclick="linkSet.checkOnlineStatusOfElements()">Check Status</a>
			<div class="netblog-clear"></div>		
		</div>
		
		<div class="progbar" id="netblog-progbar">&nbsp;</div>	
		
		<div class="body">	
			<div id="netblog-body"></div>							
		</div>
		<div class="netblog-clear"></div>
	</div>
	
	<div id="terminal"></div>
	<script type="text/javascript">
	<!--
		var delim_main = '<?php echo constant('NETBLOG_AJAX_DELIM_KEYMAIN'); ?>';
		var delim_sub = '<?php echo constant('NETBLOG_AJAX_DELIM_KEYSUB'); ?>';
		var scopeElemID = 'netblog-elem-';
		var classModified = 'mod';
		var classTrashed = 'trash';
		var classOffline = 'offline';
		var linkSet = new netblog_links();
		linkSet.init( 'linkSet', scopeElemID, classModified, classTrashed, classOffline, 'netblog-progbar', 'progbar-err' );
		
		/* ALIGN CUSTOM-SUB-MENU */
		var custMain = document.getElementById('nb-mel-custom');
		var custSub = document.getElementById('nb-mel-custom-sub');
		if( custMain != null && custSub != null ) {
			custSub.style.display = 'none';
			custSub.style.position = 'absolute';
			custSub.style.top = (custMain.offsetTop + custMain.offsetHeight) + 'px';
			custSub.style.left = custMain.offsetLeft + 'px';
		}
		function nb_toogle_custommenu()
		{
			if( custSub.style.display == 'none' )
				showPlus('nb-mel-custom-sub',0,200,true,false);//custSub.style.display = 'block';
			else hidePlus('nb-mel-custom-sub',0,200,true,false);//custSub.style.display = 'none';
		}
		
		/* FORMAT LINK FUNC */
		function netblog_linkF( id, uri, title, info, flag, ref )
		{
			var className = '';
			if( flag == 1 ) className = 'offline';
			if( flag == 3 || flag == 2 ) className = 'trash';			
			var e = '<div id="'+scopeElemID + id +'" class="'+className+'"><div class="title"><div onclick="netblog_linkE(this,\''+id+'\')">' + title + '</div></div>'+
					'<div class="uri"><div onclick="netblog_linkE(this,\''+id+'\')">' + uri + '</div></div>'+
					'<div class="info">' + info + '; '+ref+' times</div></div>';
			
			var blockID = scopeElemID + '-block-' + id;			
			
			var obj;
			if( (obj=document.getElementById(blockID)) != null ) {
				obj.innerHTML = e;				
				return '';					
			} else {
				show( ''+blockID+'', 200, 500 );
				return '<div class="elem" id="'+blockID+'" style="display:none">' + e + '</div>';
			}
		}
		
		/* MK LINK EDIT FUNC */
		function netblog_linkE( obj, uri_id )
		{
			var inputID = 'netblog-link-edit-'+uri_id;
			var inner = '<input type="text" value="' + obj.innerHTML + '" class="' + obj.parentNode.className + '" onblur="netblog_linkS(this,\''+uri_id+'\')" id="'+inputID+'" />';
			obj.parentNode.innerHTML = inner;
			document.getElementById(inputID).select();
		}
		
		/* MK LINK SAVE */
		function netblog_linkS( obj, uri_id )
		{
			var type = obj.className;
			var val = obj.value;
			
			obj.parentNode.innerHTML = '<div onclick="netblog_linkE(this,\''+uri_id+'\')">'+val+'</div>';	
			
			if( type == 'title' )
				linkSet.setTitle( uri_id, val );
			else if( type == 'uri' )
				linkSet.setUri( uri_id, val );
				
					
		}
		
		function netblog_linkRespParse( response )
		{
			var p = interpretStr( response, delim_main, delim_sub );
			var i;
			for( i=0; i<p.length; i++ ) {
				
			}
		}
		

		function netblog_mk_list( list )
		{			
			var i;
			if( list.length == 0 ||  typeof(list[0][5]) == 'undefined' ) {
				linkSet.showAll();
				document.getElementById('netblog-body').innerHTML = '<div class="empty" id="netblog-body-nothing">Nothing found</div>';
				show('netblog-body-nothing',0,1000);
			} else {
				for( i=0; i<list.length; i++ ) {
					linkSet.add( list[i][0], list[i][1], list[i][2], list[i][3], list[i][4], list[i][5] );
				}
				linkSet.showAll();				
			}
			linkSet.updateStatusBar( list.length + ' results' );
		}
		function netblog_retrieve(query)
		{			
			if( !linkSet.isBusy() ) {						
				linkSet.clear();				
				linkSet.updateStatusBar( 'Searching...' );
				document.getElementById('netblog-body').innerHTML = '<div class="empty" id="netblog-body-nothing">search ...</div>';	
				show('netblog-body-nothing',0,50);
				netblog_ajax_get_links( query, netblog_mk_list, this );
			}
		}	
		
		/* REGISTER HANDLER */
		linkSet.registerCBflush2server( netblog_ajax_send_link,this, '','','','','', '' );
		linkSet.registerCBflushed( linkSet.flushed, linkSet, '','','','', '' );
		linkSet.registerCBlinkF( netblog_linkF, this, '', '', '', '', '', '' );
		linkSet.registerPrint2Obj( 'netblog-body' );
		linkSet.registerStatusObj( 'netblog-status-save' );	
		
		netblog_retrieve('<?php echo $mel_tpl_startup ?>');
			
	//-->
	</script>	
		
	<?php
	
	echo '</div>';
}
function netblog_mel_tpl_add( $name, $val )
{
	//$name = netblog_str2alnum($name);
	if( strlen($name) == 0 ) return;
	
	$name = netblog_mel_tpl_scope() . $name;
	if( !get_option($name) ) 
		add_option($name,$val,'',false);
	else update_option($name,$val);
}
function netblog_mel_tpl_rm( $name )
{
	delete_option( netblog_mel_tpl_scope() . $name );
}
function netblog_mel_tpl_get( $name )
{
	get_option( netblog_mel_tpl_scope() . $name );
}
function netblog_mel_tpls()
{
	global $wpdb;
	$pre = netblog_mel_tpl_scope();
	$r = $wpdb->get_results("SELECT * FROM $wpdb->options WHERE option_name LIKE '$pre%'", ARRAY_A);
	$out = array();
	foreach($r as $row )
		$out[ substr($row['option_name'],strlen($pre)) ] = $row['option_value'];
	return $out;
}
function netblog_mel_tpl_scope()
{
	return 'nb-meltpl-';
}

//----------------------------------------------------------------------------------
// SETTINGS PAGE
//----------------------------------------------------------------------------------
include_once( 'core/settings.php');


//----------------------------------------------------------------------------------
// METABOX - REFERENCE MAKER
//----------------------------------------------------------------------------------
include_once( 'core/metabox_refmaker.php' );

//----------------------------------------------------------------------------------
// METABOX FOR EDIT-POST
//----------------------------------------------------------------------------------
add_action('admin_init', 'netblog_post_add_metabox');

function netblog_post_add_metabox()
{
	if( function_exists('add_meta_box') ) {
		add_meta_box('netblog_post_interface', 'Further Reading', 'netblog_post_interface', 'post', 'advanced','high');
		add_meta_box('netblog_post_interface', 'Further Reading', 'netblog_post_interface', 'page', 'advanced','high');
	} else {
		//add_action('dbx_post_advanced', 'myplugin_old_custom_box' ); 
	}
	netblog_plugin_styles();		
}

function netblog_post_interface()
{
	global $post;
	$nodeID = $post->ID;
	
	// VERIFY
	echo '<input type="hidden" name="netblog_noncename" id="netblog_noncename" value="' . 
	wp_create_nonce( plugin_basename(__FILE__) ) . '" />';
	
	$hintKeywordsExt = '';
	$t = explode(' ', get_option('netblog_websearch_keywords') );
	if( sizeof($t) > 1 )
		$hintKeywordsExt .= 'either ';
	$hintKeywordsExt .= 'with ';
	for( $i=0; $i<sizeof($t); $i++ ) {
		if( $i>0 && $i<sizeof($t)-1 ) 
			$hintKeywordsExt .= ', ';
		if( $i>0 && $i==sizeof($t)-1 ) 
			$hintKeywordsExt .= ' or with ';
		$hintKeywordsExt .= "'$t[$i]'";
	}
	
	// METABOX CONTENT
	?>	
	<div class="netblog-post-container" style="width:100%;">
		
		<div>
            <div class="input-autocomplete" style="width:100%;">      
                <div class="input-autocomplete-txt" id="input-autocomplete-txt1">
	                <input type="text" name="text-input" id="input-autocomplete1" value="" class="text-input" autocomplete="off" /></div>                     
                <div class="input-autocomplete-wnd" id="input-autocomplete-wnd1"></div>
                
                <div class="helpS">Type a name to search for posts at this site. 
                								 Preceed your query to the word wide web <?php echo $hintKeywordsExt; ?>.</div>    
            </div>
            <div class="input-autocomplete-btn" >
	            <!-- <input type="button" value="Add Link" onclick="addAdjNode(box.getCurRowID(),box.getCurRowValue())"  
	            	id="input-autocomplete-submit1" class="button"/> -->
            </div> 
            <div style="float:none; clear:both"></div>
        </div> 
        <div class="hr"></div>
        <div class="lister" id="netblog-post-container-lister"></div>
         
        
         
        <script language="javascript">
     
        /* AUTOCOMPLETE BOX */
        	if( typeof(netblog_autocomplete) == 'function' ) {
				var box = new netblog_autocomplete();
				box.setInputDefaultValue('Search for resources');
				box.setMinInputLength(<?php echo constant('NETBLOG_AUTOCOMPLETE_MINLEN'); ?>);
				box.setFooter(' <?php echo '<a href="'.constant('NETBLOG_WEBSEARCH_PROVIDER_URI').'">'.constant('NETBLOG_WEBSEARCH_PROVIDER_NAME').'</a>' ?> ');
				box.init( 'input-autocomplete-txt', 'input-autocomplete1', 'input-autocomplete-wnd1', 'box', box );				
				
				function boxFormatPrint( row )
				{
					var match = box.getInputStr();
					var title = row[0];
					var out;					
					
					if( row[6] != '' ) {
						var uriF = row[6];
						var titleF = row[0];
						var t = box.getInputStr();
						var matches = t.split(' ');
						for( i=0; i<matches.length; i++ ) {								
							var m = matches[i];
							if( m == 'www' || m == 'http://' ) continue;
							
							uriF = uriF.replace( m, '<b>'+m+'</b>' );
							
							var t = titleF.match( new RegExp( m, "gi" ) );														
							if( t != null )
							for( s=0; s<t.length; s++ )								
								titleF = titleF.replace( t[s], '<b>'+t[s]+'</b>' );
						}
						out = uriF + ' <small>' + titleF + '</small>';
					} else {
						title = title.substr(0,match.length) + '<b>'+title.substr(match.length)+'</b>';						
						var out = title + ' <small>By '+row[2]+', '+row[3]+'</small>';
						if( row[1].length > 5 )
							out += '<br /><dfn>'+row[1]+'</dfn>';
					}
					return out;
				}
				function boxFormatInput( row )
				{
					if( row[6] != '' )
						return row[6]; 
					return row[0]; 
				}
					
				box.RegisterCBFormater( this, boxFormatPrint, '' );
				box.RegisterCBFormaterInput( this, boxFormatInput, '' );
				
			} else document.getElementById('netblog-post-container-lister').innerHTML += 'Unable to load autocomplete box Handler!<br />';
			
		/* LISTER */
			if( typeof(netblog_lister) == 'function' ) { 
				var list = new netblog_lister();
				
				list.init('netblog-post-container-lister','list');
				list.setSortImmediate(false);
				list.setAppendMode(2);
				list.setSubmenuMode(2);
				list.setFormatMode(3);
				list.setOnRemoveWaitFeedback(true);
				
				/* CUSTOM ROW FORMATER */
				function formater( id, array, remove )
				{	
					if( array[5] == 'extern' ) 
						return '<a href="'+array[6]+'" class="right" >visit</a><strong>'+array[6]+'</strong> <em>'+array[0]+'</em>';
					else 	
						return '<a href="'+array[6]+'" class="right" >read</a><a href="'+array[7]+'" class="right" >edit</a>'+
							'<strong>'+array[0]+'</strong> <em>By '+array[2]+'</em><br/>'+
							'<dfn> Published on '+array[3]+' as '+array[5]+'</dfn>';
				}	
				list.registerCBFormatElem( this, formater, '','','' );
					
			} else 	document.getElementById('netblog-post-container-lister').innerHTML += 'Unable to load List Handler!';
		
		/* AJAX HANDLER */
			var delim_main = '<?php echo constant('NETBLOG_AJAX_DELIM_KEYMAIN'); ?>';
			var delim_sub = '<?php echo constant('NETBLOG_AJAX_DELIM_KEYSUB'); ?>';
			var nodeID = <?php echo $nodeID ?>;	
			
			function getChildNodes() {
				jQuery(document).ready(function($) {
					var data = {
						action: 'send_childNodes',
						nodeID: nodeID
					};
					jQuery.post(ajaxurl, data, function(response) {
						var ar = interpretStr( response, delim_main, delim_sub );
						var i;
						for( i=0; i<ar.length; i++ )
							if( ar[i].length > 1 ) {
								var id = ar[i][0];
								var title = ar[i][1];
								var auth = ar[i][2];
								var date = ar[i][3];
								var status = ar[i][4];
								var type = ar[i][5];
								var permalink = ar[i][6];
								var editlink = ar[i][7];
								list.add(id, [title,'',auth,date,status,type,permalink,editlink]);
							}		
					});
				});			
			}

			function send( inputStr ) {
				jQuery(document).ready(function($) {
					var data = {
						action: 'send_autocomplete',
						query: ''+inputStr,
						nodeID: nodeID
					};
					// since 2.8 ajaxurl is always defined in the admin header and points to admin-ajax.php
					jQuery.post(ajaxurl, data, function(response) {
						var ar = interpretStr( response, delim_main, delim_sub );					
						box.clear();
						var hasExtern = false;
						for( i=0; i<ar.length; i++ )
							if( ar[i].length > 1 ) {																							
								var type = ar[i][0];								
								if( type == 'extern' ) {									
									var title = ar[i][1];
									var uri = ar[i][2];
									box.append( hex_md5(uri), [title, '', '', '', '', 'extern', uri] );
									hasExtern = true;
								} else {
									var title = ar[i][1];
									var id = ar[i][2];
									var desc = ar[i][3];
									var auth = ar[i][4];
									var date = ar[i][5];
									var status = ar[i][6];
									box.append( id, [title,desc,auth,date,status,type,''] );
									
								}
							}
						if( ar.length == 0 )
							box.hide(0);
						else box.show(0);
						if( hasExtern )
							box.printFooter();			
					});
				});
			}
			
			function addAdjNode( adjID, e )
			{
				if( e[5] == 'extern' ) {
					jQuery(document).ready(function($) {
						var data = {
							action: 'send_newAdjNodeExtern',
							nodeID: nodeID,
							uri: e[6],
							uri_title: e[0]
						};
						jQuery.post(ajaxurl, data, function(response) {
							if(stringCompare( response, 'true' ) == 0) {
								list.addBottom( hex_md5(e[6]), [e[0],'','','','','extern',e[6],''] );
								box.setInput('');
								return true
							} else 
								alert('Cannot add link');
							return false;					
						});
					});
				} else {				
					jQuery(document).ready(function($) {
						var data = {
							action: 'send_newAdjNode',
							nodeID: nodeID,
							adjNodeID: adjID
						};
						jQuery.post(ajaxurl, data, function(response) {
							var ar = interpretStr( response, delim_main, delim_sub );
							for( i=0; i<ar.length; i++ )
								if( ar[i].length > 1 ) {
									var id = ar[i][0];
									var title = ar[i][1];
									var auth = ar[i][2];
									var date = ar[i][3];
									var status = ar[i][4];
									var type = ar[i][5];
									var permalink = ar[i][6];
									var editlink = ar[i][7];
									list.addTop(id, [title,'',auth,date,status,type,permalink,editlink]);
									box.setInput('');
								}					
						});
					});
				}
			}
			
			function removeAdjNode( adjID, e )
			{
				var childNode = adjID;
				if( e[5] == 'extern' )
					childNode = e[6];

				jQuery(document).ready(function($) {
					var data = {
						action: 'send_rmAdjNode',
						nodeID: nodeID,
						adjNodeID: childNode
					};
					jQuery.post(ajaxurl, data, function(response) {								
						if( stringCompare(response,'true') == 0 ) {
							list.removeOK(true);
							return true;							
						} else if( list.findRowID(adjID) != '' ) {
							alert('Error: cannot remove node');
							list.removeOK(false);
							return false;
						}
					});
				});						
			}
			function stringCompare( str1, str2 )
			{
				if( str1 < str2 ) return -1;
				if( str1 > str2 ) return 1;
				return 0;
			}
			
		/* RETRIEVE NEAR-MATCHED BASED ON [STR] -> AUTOCOMPLETE_BOX */
			box.RegisterCBAppend( this, send, '' );
			
		/* SEND AUTOCOMPLETE_BOX -> NEW NODE HANDLER -> SERVER | LISTER */
			box.RegisterCBChosen( this, addAdjNode, '', '' );
			
		/* SEND LISTER-REMOVED -> SERVER */
			list.registerCBOnRemoveElem( this, removeAdjNode, '', '' );
				
			getChildNodes();			
		</script>	

	</div>
	
	<?php
}


//----------------------------------------------------------------------------------
// FOOTNOTE
//----------------------------------------------------------------------------------
include_once( 'core/footnote.php' );

//----------------------------------------------------------------------------------
// CITATION
//----------------------------------------------------------------------------------
include_once( 'core/cite.php' );

//----------------------------------------------------------------------------------
// CAPTION
//----------------------------------------------------------------------------------
include_once( 'core/caption.php' );

//----------------------------------------------------------------------------------
// SERVER-SIDE AJAX-HANDLER
//----------------------------------------------------------------------------------
include_once( 'core/sshndl_ajax.php' );


//----------------------------------------------------------------------------------
// Widgets
//----------------------------------------------------------------------------------
include_once( 'netblogWidgets.php' );









?>